@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -32,7 +32,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Agent]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Agent | None:
     if response.status_code == 200:
         response_200 = Agent.from_dict(response.json())
 
@@ -85,7 +85,7 @@ def sync(
     *,
     client: Union[Client],
     body: Agent,
-) -> Optional[Agent]:
+) -> Agent | None:
     """Create agent by name
 
     Args:
@@ -136,7 +136,7 @@ async def asyncio(
     *,
     client: Union[Client],
     body: Agent,
-) -> Optional[Agent]:
+) -> Agent | None:
     """Create agent by name
 
     Args:
