@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -20,7 +20,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Sandbox]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Sandbox | None:
     if response.status_code == 200:
         response_200 = Sandbox.from_dict(response.json())
 
@@ -75,7 +75,7 @@ def sync(
     sandbox_name: str,
     *,
     client: Union[Client],
-) -> Optional[Sandbox]:
+) -> Sandbox | None:
     """Delete Sandbox
 
      Deletes a Sandbox by name.
@@ -130,7 +130,7 @@ async def asyncio(
     sandbox_name: str,
     *,
     client: Union[Client],
-) -> Optional[Sandbox]:
+) -> Sandbox | None:
     """Delete Sandbox
 
      Deletes a Sandbox by name.
