@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -21,7 +21,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Preview]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Preview | None:
     if response.status_code == 200:
         response_200 = Preview.from_dict(response.json())
 
@@ -80,7 +80,7 @@ def sync(
     preview_name: str,
     *,
     client: Union[Client],
-) -> Optional[Preview]:
+) -> Preview | None:
     """Delete Sandbox Preview
 
      Deletes a Sandbox Preview by name.
@@ -141,7 +141,7 @@ async def asyncio(
     preview_name: str,
     *,
     client: Union[Client],
-) -> Optional[Preview]:
+) -> Preview | None:
     """Delete Sandbox Preview
 
      Deletes a Sandbox Preview by name.
