@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union, cast
+from typing import Any, Union, cast
 
 import httpx
 
@@ -20,7 +20,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, StopSandbox]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Union[Any, StopSandbox] | None:
     if response.status_code == 200:
         response_200 = StopSandbox.from_dict(response.json())
 
@@ -78,7 +78,7 @@ def sync(
     sandbox_name: str,
     *,
     client: Union[Client],
-) -> Optional[Union[Any, StopSandbox]]:
+) -> Union[Any, StopSandbox] | None:
     """Stop Sandbox
 
      Stops a Sandbox by name.
@@ -133,7 +133,7 @@ async def asyncio(
     sandbox_name: str,
     *,
     client: Union[Client],
-) -> Optional[Union[Any, StopSandbox]]:
+) -> Union[Any, StopSandbox] | None:
     """Stop Sandbox
 
      Stops a Sandbox by name.
