@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -34,7 +34,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Preview]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Preview | None:
     if response.status_code == 200:
         response_200 = Preview.from_dict(response.json())
 
@@ -97,7 +97,7 @@ def sync(
     *,
     client: Union[Client],
     body: Preview,
-) -> Optional[Preview]:
+) -> Preview | None:
     """Update Sandbox Preview
 
      Updates a Sandbox Preview by name.
@@ -164,7 +164,7 @@ async def asyncio(
     *,
     client: Union[Client],
     body: Preview,
-) -> Optional[Preview]:
+) -> Preview | None:
     """Update Sandbox Preview
 
      Updates a Sandbox Preview by name.
