@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -18,7 +18,7 @@ def _get_kwargs() -> dict[str, Any]:
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Configuration]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Configuration | None:
     if response.status_code == 200:
         response_200 = Configuration.from_dict(response.json())
 
@@ -64,7 +64,7 @@ def sync_detailed(
 def sync(
     *,
     client: Union[Client],
-) -> Optional[Configuration]:
+) -> Configuration | None:
     """List all configurations
 
     Raises:
@@ -104,7 +104,7 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Union[Client],
-) -> Optional[Configuration]:
+) -> Configuration | None:
     """List all configurations
 
     Raises:
