@@ -1,26 +1,35 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
 from ... import errors
 from ...client import Client
 from ...models.function import Function
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
     function_name: str,
+    *,
+    show_secrets: Union[Unset, bool] = UNSET,
 ) -> dict[str, Any]:
+    params: dict[str, Any] = {}
+
+    params["show_secrets"] = show_secrets
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     _kwargs: dict[str, Any] = {
         "method": "get",
         "url": f"/functions/{function_name}",
+        "params": params,
     }
 
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Function]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Function | None:
     if response.status_code == 200:
         response_200 = Function.from_dict(response.json())
 
@@ -44,11 +53,13 @@ def sync_detailed(
     function_name: str,
     *,
     client: Union[Client],
+    show_secrets: Union[Unset, bool] = UNSET,
 ) -> Response[Function]:
     """Get function by name
 
     Args:
         function_name (str):
+        show_secrets (Union[Unset, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -60,6 +71,7 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         function_name=function_name,
+        show_secrets=show_secrets,
     )
 
     response = client.get_httpx_client().request(
@@ -73,11 +85,13 @@ def sync(
     function_name: str,
     *,
     client: Union[Client],
-) -> Optional[Function]:
+    show_secrets: Union[Unset, bool] = UNSET,
+) -> Function | None:
     """Get function by name
 
     Args:
         function_name (str):
+        show_secrets (Union[Unset, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -90,6 +104,7 @@ def sync(
     return sync_detailed(
         function_name=function_name,
         client=client,
+        show_secrets=show_secrets,
     ).parsed
 
 
@@ -97,11 +112,13 @@ async def asyncio_detailed(
     function_name: str,
     *,
     client: Union[Client],
+    show_secrets: Union[Unset, bool] = UNSET,
 ) -> Response[Function]:
     """Get function by name
 
     Args:
         function_name (str):
+        show_secrets (Union[Unset, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -113,6 +130,7 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         function_name=function_name,
+        show_secrets=show_secrets,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -124,11 +142,13 @@ async def asyncio(
     function_name: str,
     *,
     client: Union[Client],
-) -> Optional[Function]:
+    show_secrets: Union[Unset, bool] = UNSET,
+) -> Function | None:
     """Get function by name
 
     Args:
         function_name (str):
+        show_secrets (Union[Unset, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -142,5 +162,6 @@ async def asyncio(
         await asyncio_detailed(
             function_name=function_name,
             client=client,
+            show_secrets=show_secrets,
         )
     ).parsed
