@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -18,7 +18,7 @@ def _get_kwargs() -> dict[str, Any]:
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[list["Function"]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> list["Function"] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -69,7 +69,7 @@ def sync_detailed(
 def sync(
     *,
     client: Union[Client],
-) -> Optional[list["Function"]]:
+) -> list["Function"] | None:
     """List all functions
 
     Raises:
@@ -109,7 +109,7 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Union[Client],
-) -> Optional[list["Function"]]:
+) -> list["Function"] | None:
     """List all functions
 
     Raises:
