@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -33,7 +33,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[IntegrationConnection]:
+def _parse_response(*, client: Client, response: httpx.Response) -> IntegrationConnection | None:
     if response.status_code == 200:
         response_200 = IntegrationConnection.from_dict(response.json())
 
@@ -92,7 +92,7 @@ def sync(
     *,
     client: Union[Client],
     body: IntegrationConnection,
-) -> Optional[IntegrationConnection]:
+) -> IntegrationConnection | None:
     """Update integration connection
 
      Update an integration connection by integration name and connection name.
@@ -153,7 +153,7 @@ async def asyncio(
     *,
     client: Union[Client],
     body: IntegrationConnection,
-) -> Optional[IntegrationConnection]:
+) -> IntegrationConnection | None:
     """Update integration connection
 
      Update an integration connection by integration name and connection name.
