@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union, cast
+from typing import Any, Union, cast
 
 import httpx
 
@@ -18,9 +18,7 @@ def _get_kwargs() -> dict[str, Any]:
     return _kwargs
 
 
-def _parse_response(
-    *, client: Client, response: httpx.Response
-) -> Optional[Union[Any, list["PendingInvitationRender"]]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Union[Any, list["PendingInvitationRender"]] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -78,7 +76,7 @@ def sync_detailed(
 def sync(
     *,
     client: Union[Client],
-) -> Optional[Union[Any, list["PendingInvitationRender"]]]:
+) -> Union[Any, list["PendingInvitationRender"]] | None:
     """List pending invitations
 
      Returns a list of all pending invitations in the workspace.
@@ -122,7 +120,7 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Union[Client],
-) -> Optional[Union[Any, list["PendingInvitationRender"]]]:
+) -> Union[Any, list["PendingInvitationRender"]] | None:
     """List pending invitations
 
      Returns a list of all pending invitations in the workspace.
