@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -20,7 +20,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[list["RevisionMetadata"]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> list["RevisionMetadata"] | None:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -80,7 +80,7 @@ def sync(
     job_id: str,
     *,
     client: Union[Client],
-) -> Optional[list["RevisionMetadata"]]:
+) -> list["RevisionMetadata"] | None:
     """List job revisions
 
      Returns revisions for a job by name.
@@ -135,7 +135,7 @@ async def asyncio(
     job_id: str,
     *,
     client: Union[Client],
-) -> Optional[list["RevisionMetadata"]]:
+) -> list["RevisionMetadata"] | None:
     """List job revisions
 
      Returns revisions for a job by name.
