@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -32,7 +32,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Model]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Model | None:
     if response.status_code == 200:
         response_200 = Model.from_dict(response.json())
 
@@ -87,7 +87,7 @@ def sync(
     *,
     client: Union[Client],
     body: Model,
-) -> Optional[Model]:
+) -> Model | None:
     """Create model
 
      Creates a model.
@@ -142,7 +142,7 @@ async def asyncio(
     *,
     client: Union[Client],
     body: Model,
-) -> Optional[Model]:
+) -> Model | None:
     """Create model
 
      Creates a model.
