@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -22,7 +22,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[DeleteWorkspaceServiceAccountResponse200]:
+def _parse_response(*, client: Client, response: httpx.Response) -> DeleteWorkspaceServiceAccountResponse200 | None:
     if response.status_code == 200:
         response_200 = DeleteWorkspaceServiceAccountResponse200.from_dict(response.json())
 
@@ -77,7 +77,7 @@ def sync(
     client_id: str,
     *,
     client: Union[Client],
-) -> Optional[DeleteWorkspaceServiceAccountResponse200]:
+) -> DeleteWorkspaceServiceAccountResponse200 | None:
     """Delete workspace service account
 
      Deletes a service account.
@@ -132,7 +132,7 @@ async def asyncio(
     client_id: str,
     *,
     client: Union[Client],
-) -> Optional[DeleteWorkspaceServiceAccountResponse200]:
+) -> DeleteWorkspaceServiceAccountResponse200 | None:
     """Delete workspace service account
 
      Deletes a service account.
