@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -20,7 +20,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Volume]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Volume | None:
     if response.status_code == 200:
         response_200 = Volume.from_dict(response.json())
 
@@ -75,7 +75,7 @@ def sync(
     volume_name: str,
     *,
     client: Union[Client],
-) -> Optional[Volume]:
+) -> Volume | None:
     """Delete volume
 
      Deletes a volume by name.
@@ -130,7 +130,7 @@ async def asyncio(
     volume_name: str,
     *,
     client: Union[Client],
-) -> Optional[Volume]:
+) -> Volume | None:
     """Delete volume
 
      Deletes a volume by name.
