@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 
@@ -20,7 +20,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[PendingInvitation]:
+def _parse_response(*, client: Client, response: httpx.Response) -> PendingInvitation | None:
     if response.status_code == 200:
         response_200 = PendingInvitation.from_dict(response.json())
 
@@ -75,7 +75,7 @@ def sync(
     workspace_name: str,
     *,
     client: Union[Client],
-) -> Optional[PendingInvitation]:
+) -> PendingInvitation | None:
     """Decline invitation to workspace
 
      Declines an invitation to a workspace.
@@ -130,7 +130,7 @@ async def asyncio(
     workspace_name: str,
     *,
     client: Union[Client],
-) -> Optional[PendingInvitation]:
+) -> PendingInvitation | None:
     """Decline invitation to workspace
 
      Declines an invitation to a workspace.
