@@ -1,5 +1,5 @@
 from http import HTTPStatus
-from typing import Any, Optional, Union, cast
+from typing import Any, Union, cast
 
 import httpx
 
@@ -33,7 +33,7 @@ def _get_kwargs(
     return _kwargs
 
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, PendingInvitation]]:
+def _parse_response(*, client: Client, response: httpx.Response) -> Union[Any, PendingInvitation] | None:
     if response.status_code == 200:
         response_200 = PendingInvitation.from_dict(response.json())
 
@@ -94,7 +94,7 @@ def sync(
     *,
     client: Union[Client],
     body: InviteWorkspaceUserBody,
-) -> Optional[Union[Any, PendingInvitation]]:
+) -> Union[Any, PendingInvitation] | None:
     """Invite user to workspace
 
      Invites a user to the workspace by email.
@@ -149,7 +149,7 @@ async def asyncio(
     *,
     client: Union[Client],
     body: InviteWorkspaceUserBody,
-) -> Optional[Union[Any, PendingInvitation]]:
+) -> Union[Any, PendingInvitation] | None:
     """Invite user to workspace
 
      Invites a user to the workspace by email.
