@@ -1,5 +1,5 @@
 import ssl
-from typing import Any, Optional, Union
+from typing import Any, Union
 
 import httpx
 from attrs import define, evolve, field
@@ -42,12 +42,12 @@ class Client:
     _cookies: dict[str, str] = field(factory=dict, kw_only=True, alias="cookies")
     _headers: dict[str, str] = field(factory=dict, kw_only=True, alias="headers")
     _auth: httpx.Auth = field(default=None, alias="auth")
-    _timeout: Optional[httpx.Timeout] = field(default=None, kw_only=True, alias="timeout")
+    _timeout: httpx.Timeout | None = field(default=None, kw_only=True, alias="timeout")
     _verify_ssl: Union[str, bool, ssl.SSLContext] = field(default=True, kw_only=True, alias="verify_ssl")
     _follow_redirects: bool = field(default=False, kw_only=True, alias="follow_redirects")
     _httpx_args: dict[str, Any] = field(factory=dict, kw_only=True, alias="httpx_args")
-    _client: Optional[httpx.Client] = field(default=None, init=False)
-    _async_client: Optional[httpx.AsyncClient] = field(default=None, init=False)
+    _client: httpx.Client | None = field(default=None, init=False)
+    _async_client: httpx.AsyncClient | None = field(default=None, init=False)
 
     def with_base_url(self, base_url: str) -> "Client":
         """Get a new client matching this one with a new base URL"""
