@@ -27,12 +27,14 @@ class MCPDefinition:
         enterprise (Union[Unset, bool]): If the artifact is enterprise
         entrypoint (Union[Unset, MCPDefinitionEntrypoint]): Entrypoint of the artifact
         form (Union[Unset, MCPDefinitionForm]): Form of the artifact
+        hidden (Union[Unset, bool]): If the artifact is hidden
         hidden_secrets (Union[Unset, list[str]]): Hidden secrets of the artifact
         icon (Union[Unset, str]): Icon of the artifact
         image (Union[Unset, str]): Image of the artifact
         integration (Union[Unset, str]): Integration of the artifact
         long_description (Union[Unset, str]): Long description of the artifact
         name (Union[Unset, str]): Name of the artifact
+        transport (Union[Unset, str]): Transport compatibility for the MCP, can be "websocket" or "http-stream"
         url (Union[Unset, str]): URL of the artifact
     """
 
@@ -45,12 +47,14 @@ class MCPDefinition:
     enterprise: Union[Unset, bool] = UNSET
     entrypoint: Union[Unset, "MCPDefinitionEntrypoint"] = UNSET
     form: Union[Unset, "MCPDefinitionForm"] = UNSET
+    hidden: Union[Unset, bool] = UNSET
     hidden_secrets: Union[Unset, list[str]] = UNSET
     icon: Union[Unset, str] = UNSET
     image: Union[Unset, str] = UNSET
     integration: Union[Unset, str] = UNSET
     long_description: Union[Unset, str] = UNSET
     name: Union[Unset, str] = UNSET
+    transport: Union[Unset, str] = UNSET
     url: Union[Unset, str] = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -83,6 +87,8 @@ class MCPDefinition:
         elif self.form and isinstance(self.form, dict):
             form = self.form
 
+        hidden = self.hidden
+
         hidden_secrets: Union[Unset, list[str]] = UNSET
         if not isinstance(self.hidden_secrets, Unset):
             hidden_secrets = self.hidden_secrets
@@ -97,6 +103,8 @@ class MCPDefinition:
 
         name = self.name
 
+        transport = self.transport
+
         url = self.url
 
         field_dict: dict[str, Any] = {}
@@ -120,6 +128,8 @@ class MCPDefinition:
             field_dict["entrypoint"] = entrypoint
         if form is not UNSET:
             field_dict["form"] = form
+        if hidden is not UNSET:
+            field_dict["hidden"] = hidden
         if hidden_secrets is not UNSET:
             field_dict["hiddenSecrets"] = hidden_secrets
         if icon is not UNSET:
@@ -132,6 +142,8 @@ class MCPDefinition:
             field_dict["longDescription"] = long_description
         if name is not UNSET:
             field_dict["name"] = name
+        if transport is not UNSET:
+            field_dict["transport"] = transport
         if url is not UNSET:
             field_dict["url"] = url
 
@@ -173,6 +185,8 @@ class MCPDefinition:
         else:
             form = MCPDefinitionForm.from_dict(_form)
 
+        hidden = d.pop("hidden", UNSET)
+
         hidden_secrets = cast(list[str], d.pop("hiddenSecrets", UNSET))
 
         icon = d.pop("icon", UNSET)
@@ -185,6 +199,8 @@ class MCPDefinition:
 
         name = d.pop("name", UNSET)
 
+        transport = d.pop("transport", UNSET)
+
         url = d.pop("url", UNSET)
 
         mcp_definition = cls(
@@ -197,12 +213,14 @@ class MCPDefinition:
             enterprise=enterprise,
             entrypoint=entrypoint,
             form=form,
+            hidden=hidden,
             hidden_secrets=hidden_secrets,
             icon=icon,
             image=image,
             integration=integration,
             long_description=long_description,
             name=name,
+            transport=transport,
             url=url,
         )
 
