@@ -6,9 +6,11 @@ from attrs import field as _attrs_field
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.last_n_requests_metric import LastNRequestsMetric
     from ..models.metrics_models import MetricsModels
     from ..models.metrics_request_total_per_code import MetricsRequestTotalPerCode
     from ..models.metrics_rps_per_code import MetricsRpsPerCode
+    from ..models.request_total_response_data import RequestTotalResponseData
 
 
 T = TypeVar("T", bound="Metrics")
@@ -22,8 +24,8 @@ class Metrics:
         agents (Union[Unset, Any]): Metrics for agents
         functions (Union[Unset, Any]): Metrics for functions
         inference_global (Union[Unset, list[Any]]): Historical requests for all resources globally
-        items (Union[Unset, list[Any]]): Historical requests for all resources globally
-        last_n_requests (Union[Unset, int]): Metric value
+        items (Union[Unset, list['RequestTotalResponseData']]): Historical requests for all resources globally
+        last_n_requests (Union[Unset, list['LastNRequestsMetric']]): Metric value
         models (Union[Unset, MetricsModels]): Metrics for models
         request_total (Union[Unset, float]): Number of requests for all resources globally
         request_total_per_code (Union[Unset, MetricsRequestTotalPerCode]): Number of requests for all resources globally
@@ -37,8 +39,8 @@ class Metrics:
     agents: Union[Unset, Any] = UNSET
     functions: Union[Unset, Any] = UNSET
     inference_global: Union[Unset, list[Any]] = UNSET
-    items: Union[Unset, list[Any]] = UNSET
-    last_n_requests: Union[Unset, int] = UNSET
+    items: Union[Unset, list["RequestTotalResponseData"]] = UNSET
+    last_n_requests: Union[Unset, list["LastNRequestsMetric"]] = UNSET
     models: Union[Unset, "MetricsModels"] = UNSET
     request_total: Union[Unset, float] = UNSET
     request_total_per_code: Union[Unset, "MetricsRequestTotalPerCode"] = UNSET
@@ -56,11 +58,25 @@ class Metrics:
         if not isinstance(self.inference_global, Unset):
             inference_global = self.inference_global
 
-        items: Union[Unset, list[Any]] = UNSET
+        items: Union[Unset, list[dict[str, Any]]] = UNSET
         if not isinstance(self.items, Unset):
-            items = self.items
+            items = []
+            for items_item_data in self.items:
+                if type(items_item_data) is dict:
+                    items_item = items_item_data
+                else:
+                    items_item = items_item_data.to_dict()
+                items.append(items_item)
 
-        last_n_requests = self.last_n_requests
+        last_n_requests: Union[Unset, list[dict[str, Any]]] = UNSET
+        if not isinstance(self.last_n_requests, Unset):
+            last_n_requests = []
+            for last_n_requests_item_data in self.last_n_requests:
+                if type(last_n_requests_item_data) is dict:
+                    last_n_requests_item = last_n_requests_item_data
+                else:
+                    last_n_requests_item = last_n_requests_item_data.to_dict()
+                last_n_requests.append(last_n_requests_item)
 
         models: Union[Unset, dict[str, Any]] = UNSET
         if self.models and not isinstance(self.models, Unset) and not isinstance(self.models, dict):
@@ -120,9 +136,11 @@ class Metrics:
 
     @classmethod
     def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
+        from ..models.last_n_requests_metric import LastNRequestsMetric
         from ..models.metrics_models import MetricsModels
         from ..models.metrics_request_total_per_code import MetricsRequestTotalPerCode
         from ..models.metrics_rps_per_code import MetricsRpsPerCode
+        from ..models.request_total_response_data import RequestTotalResponseData
 
         if not src_dict:
             return None
@@ -133,9 +151,19 @@ class Metrics:
 
         inference_global = cast(list[Any], d.pop("inferenceGlobal", UNSET))
 
-        items = cast(list[Any], d.pop("items", UNSET))
+        items = []
+        _items = d.pop("items", UNSET)
+        for items_item_data in _items or []:
+            items_item = RequestTotalResponseData.from_dict(items_item_data)
 
-        last_n_requests = d.pop("lastNRequests", UNSET)
+            items.append(items_item)
+
+        last_n_requests = []
+        _last_n_requests = d.pop("lastNRequests", UNSET)
+        for last_n_requests_item_data in _last_n_requests or []:
+            last_n_requests_item = LastNRequestsMetric.from_dict(last_n_requests_item_data)
+
+            last_n_requests.append(last_n_requests_item)
 
         _models = d.pop("models", UNSET)
         models: Union[Unset, MetricsModels]
