@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -10,6 +10,7 @@ if TYPE_CHECKING:
         RequestTotalMetricRequestTotalPerCode,
     )
     from ..models.request_total_metric_rps_per_code import RequestTotalMetricRpsPerCode
+    from ..models.request_total_response_data import RequestTotalResponseData
 
 
 T = TypeVar("T", bound="RequestTotalMetric")
@@ -20,7 +21,7 @@ class RequestTotalMetric:
     """Metrics for request total
 
     Attributes:
-        items (Union[Unset, list[Any]]): Historical requests for all resources globally
+        items (Union[Unset, list['RequestTotalResponseData']]): Historical requests for all resources globally
         request_total (Union[Unset, float]): Number of requests for all resources globally
         request_total_per_code (Union[Unset, RequestTotalMetricRequestTotalPerCode]): Number of requests for all
             resources globally per code
@@ -28,7 +29,7 @@ class RequestTotalMetric:
         rps_per_code (Union[Unset, RequestTotalMetricRpsPerCode]): Number of requests for all resources globally
     """
 
-    items: Union[Unset, list[Any]] = UNSET
+    items: Union[Unset, list["RequestTotalResponseData"]] = UNSET
     request_total: Union[Unset, float] = UNSET
     request_total_per_code: Union[Unset, "RequestTotalMetricRequestTotalPerCode"] = UNSET
     rps: Union[Unset, float] = UNSET
@@ -36,9 +37,15 @@ class RequestTotalMetric:
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        items: Union[Unset, list[Any]] = UNSET
+        items: Union[Unset, list[dict[str, Any]]] = UNSET
         if not isinstance(self.items, Unset):
-            items = self.items
+            items = []
+            for items_item_data in self.items:
+                if type(items_item_data) is dict:
+                    items_item = items_item_data
+                else:
+                    items_item = items_item_data.to_dict()
+                items.append(items_item)
 
         request_total = self.request_total
 
@@ -82,11 +89,17 @@ class RequestTotalMetric:
             RequestTotalMetricRequestTotalPerCode,
         )
         from ..models.request_total_metric_rps_per_code import RequestTotalMetricRpsPerCode
+        from ..models.request_total_response_data import RequestTotalResponseData
 
         if not src_dict:
             return None
         d = src_dict.copy()
-        items = cast(list[Any], d.pop("items", UNSET))
+        items = []
+        _items = d.pop("items", UNSET)
+        for items_item_data in _items or []:
+            items_item = RequestTotalResponseData.from_dict(items_item_data)
+
+            items.append(items_item)
 
         request_total = d.pop("requestTotal", UNSET)
 
