@@ -17,22 +17,23 @@ class TimeToFirstTokenOverTimeMetrics:
     """Time to first token over time metrics
 
     Attributes:
-        time_to_first_token_over_time (Union[Unset, RequestDurationOverTimeMetric]): Request duration over time metric
+        time_to_first_token_over_time (Union[Unset, list['RequestDurationOverTimeMetric']]): Time to first token over
+            time
     """
 
-    time_to_first_token_over_time: Union[Unset, "RequestDurationOverTimeMetric"] = UNSET
+    time_to_first_token_over_time: Union[Unset, list["RequestDurationOverTimeMetric"]] = UNSET
     additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
-        time_to_first_token_over_time: Union[Unset, dict[str, Any]] = UNSET
-        if (
-            self.time_to_first_token_over_time
-            and not isinstance(self.time_to_first_token_over_time, Unset)
-            and not isinstance(self.time_to_first_token_over_time, dict)
-        ):
-            time_to_first_token_over_time = self.time_to_first_token_over_time.to_dict()
-        elif self.time_to_first_token_over_time and isinstance(self.time_to_first_token_over_time, dict):
-            time_to_first_token_over_time = self.time_to_first_token_over_time
+        time_to_first_token_over_time: Union[Unset, list[dict[str, Any]]] = UNSET
+        if not isinstance(self.time_to_first_token_over_time, Unset):
+            time_to_first_token_over_time = []
+            for time_to_first_token_over_time_item_data in self.time_to_first_token_over_time:
+                if type(time_to_first_token_over_time_item_data) is dict:
+                    time_to_first_token_over_time_item = time_to_first_token_over_time_item_data
+                else:
+                    time_to_first_token_over_time_item = time_to_first_token_over_time_item_data.to_dict()
+                time_to_first_token_over_time.append(time_to_first_token_over_time_item)
 
         field_dict: dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -49,12 +50,14 @@ class TimeToFirstTokenOverTimeMetrics:
         if not src_dict:
             return None
         d = src_dict.copy()
+        time_to_first_token_over_time = []
         _time_to_first_token_over_time = d.pop("timeToFirstTokenOverTime", UNSET)
-        time_to_first_token_over_time: Union[Unset, RequestDurationOverTimeMetric]
-        if isinstance(_time_to_first_token_over_time, Unset):
-            time_to_first_token_over_time = UNSET
-        else:
-            time_to_first_token_over_time = RequestDurationOverTimeMetric.from_dict(_time_to_first_token_over_time)
+        for time_to_first_token_over_time_item_data in _time_to_first_token_over_time or []:
+            time_to_first_token_over_time_item = RequestDurationOverTimeMetric.from_dict(
+                time_to_first_token_over_time_item_data
+            )
+
+            time_to_first_token_over_time.append(time_to_first_token_over_time_item)
 
         time_to_first_token_over_time_metrics = cls(
             time_to_first_token_over_time=time_to_first_token_over_time,
