@@ -1,7 +1,8 @@
 import asyncio
 import io
 import json
-from typing import Any, Callable, Dict, List, Optional, Union
+from pathlib import Path
+from typing import Any, Callable, Dict, List, Union
 
 import httpx
 
@@ -12,8 +13,9 @@ from .types import CopyResponse, SandboxConfiguration, SandboxFilesystemFile, Wa
 
 
 class SandboxFileSystem(SandboxAction):
-    def __init__(self, sandbox_config: SandboxConfiguration):
+    def __init__(self, sandbox_config: SandboxConfiguration, process=None):
         super().__init__(sandbox_config)
+        self.process = process
 
     async def mkdir(self, path: str, permissions: str = "0755") -> SuccessResponse:
         path = self.format_path(path)
@@ -33,12 +35,24 @@ class SandboxFileSystem(SandboxAction):
             self.handle_response_error(response)
             return SuccessResponse.from_dict(response.json())
 
-    async def write_binary(self, path: str, content: Union[bytes, bytearray]) -> SuccessResponse:
-        """Write binary content to a file."""
+    async def write_binary(self, path: str, content: Union[bytes, bytearray, str]) -> SuccessResponse:
+        """Write binary content to a file.
+
+        Args:
+            path: The path in the sandbox to write to
+            content: Binary content as bytes, bytearray, or string path to a local file
+
+        Returns:
+            SuccessResponse indicating success
+        """
         path = self.format_path(path)
 
+        # If content is a string, treat it as a file path and read it
+        if isinstance(content, str):
+            local_path = Path(content)
+            content = local_path.read_bytes()
         # Convert bytearray to bytes if necessary
-        if isinstance(content, bytearray):
+        elif isinstance(content, bytearray):
             content = bytes(content)
 
         # Wrap binary content in BytesIO to provide file-like interface
@@ -65,7 +79,7 @@ class SandboxFileSystem(SandboxAction):
     async def write_tree(
         self,
         files: List[Union[SandboxFilesystemFile, Dict[str, Any]]],
-        destination_path: Optional[str] = None,
+        destination_path: str | None = None,
     ) -> Directory:
         """Write multiple files in a tree structure."""
         files_dict = {}
@@ -97,6 +111,42 @@ class SandboxFileSystem(SandboxAction):
                 return data["content"]
             raise Exception("Unsupported file type")
 
+    async def read_binary(self, path: str) -> bytes:
+        """Read binary content from a file.
+
+        Args:
+            path: The path in the sandbox to read from
+
+        Returns:
+            Binary content as bytes
+        """
+        path = self.format_path(path)
+
+        url = f"{self.url}/filesystem/{path}"
+        headers = {
+            **settings.headers,
+            **self.sandbox_config.headers,
+            "Accept": "application/octet-stream",
+        }
+
+        async with self.get_client() as client_instance:
+            response = await client_instance.get(url, headers=headers)
+            self.handle_response_error(response)
+            return response.content
+
+    async def download(self, src: str, destination_path: str, mode: int = 0o644) -> None:
+        """Download a file from the sandbox to the local filesystem.
+
+        Args:
+            src: The path in the sandbox to download from
+            destination_path: The local path to save to
+            mode: File permissions mode (default: 0o644)
+        """
+        content = await self.read_binary(src)
+        local_path = Path(destination_path)
+        local_path.write_bytes(content)
+        local_path.chmod(mode)
+
     async def rm(self, path: str, recursive: bool = False) -> SuccessResponse:
         path = self.format_path(path)
 
@@ -118,65 +168,41 @@ class SandboxFileSystem(SandboxAction):
                 raise Exception('{"error": "Directory not found"}')
             return Directory.from_dict(data)
 
-    async def cp(self, source: str, destination: str) -> CopyResponse:
-        source = self.format_path(source)
-        destination = self.format_path(destination)
+    async def cp(self, source: str, destination: str, max_wait: int = 180000) -> CopyResponse:
+        """Copy files or directories using the cp command.
 
-        async with self.get_client() as client_instance:
-            response = await client_instance.get(f"/filesystem/{source}")
-            self.handle_response_error(response)
+        Args:
+            source: Source path
+            destination: Destination path
+            max_wait: Maximum time to wait for the copy operation in milliseconds (default: 180000)
+        """
+        if not self.process:
+            raise Exception("Process instance not available. Cannot execute cp command.")
 
-            data = response.json()
-            if "files" in data or "subdirectories" in data:
-                # Create destination directory
-                await self.mkdir(destination)
+        # Execute cp -r command
+        process = await self.process.exec({
+            "command": f"cp -r {source} {destination}"
+        })
 
-                # Process subdirectories in batches of 5
-                subdirectories = data.get("subdirectories", [])
-                for i in range(0, len(subdirectories), 5):
-                    batch = subdirectories[i : i + 5]
-                    await asyncio.gather(
-                        *[
-                            self.cp(
-                                subdir.get("path", f"{source}/{subdir.get('path', '')}"),
-                                f"{destination}/{subdir.get('path', '')}",
-                            )
-                            for subdir in batch
-                        ]
-                    )
+        # Wait for process to complete
+        process = await self.process.wait(process.pid, max_wait=max_wait, interval=100)
 
-                # Process files in batches of 10
-                files = data.get("files", [])
-                for i in range(0, len(files), 10):
-                    batch = files[i : i + 10]
-                    tasks = []
-                    for file in batch:
-                        source_path = file.get("path", f"{source}/{file.get('path', '')}")
-                        dest_path = f"{destination}/{file.get('path', '')}"
-                        tasks.append(self._copy_file(source_path, dest_path))
-                    await asyncio.gather(*tasks)
+        # Check if process failed
+        if process.status == "failed":
+            logs = process.logs if hasattr(process, "logs") else "Unknown error"
+            raise Exception(f"Could not copy {source} to {destination} cause: {logs}")
 
-                return CopyResponse(
-                    message="Directory copied successfully", source=source, destination=destination
-                )
-            elif "content" in data:
-                await self.write(destination, data["content"])
-                return CopyResponse(
-                    message="File copied successfully", source=source, destination=destination
-                )
-
-        raise Exception("Unsupported file type")
-
-    async def _copy_file(self, source_path: str, dest_path: str):
-        """Helper method to copy a single file."""
-        content = await self.read(source_path)
-        await self.write(dest_path, content)
+        return CopyResponse(
+            message="Files copied",
+            source=source,
+            destination=destination
+        )
 
     def watch(
         self,
         path: str,
         callback: Callable[[WatchEvent], None],
-        options: Optional[Dict[str, Any]] = None,
+        options: Dict[str, Any] | None = None,
     ) -> Dict[str, Callable]:
         """Watch for file system changes."""
         path = self.format_path(path)
@@ -187,21 +213,18 @@ class SandboxFileSystem(SandboxAction):
 
         async def start_watching():
             nonlocal closed
-
             params = {}
             if options.get("ignore"):
                 params["ignore"] = ",".join(options["ignore"])
 
-            url = f"{self.url}/filesystem/{path}/watch"
+            url = f"{self.url}/watch/filesystem/{path}"
             headers = {**settings.headers, **self.sandbox_config.headers}
-
             async with httpx.AsyncClient() as client_instance:
                 async with client_instance.stream(
                     "GET", url, params=params, headers=headers
                 ) as response:
                     if not response.is_success:
                         raise Exception(f"Failed to start watching: {response.status_code}")
-
                     buffer = ""
                     async for chunk in response.aiter_text():
                         if closed:
@@ -216,6 +239,10 @@ class SandboxFileSystem(SandboxAction):
                             if not line:
                                 continue
 
+                            # Skip keepalive messages
+                            if line.startswith("[keepalive]"):
+                                continue
+
                             try:
                                 file_event_data = json.loads(line)
                                 file_event = WatchEvent(
@@ -241,7 +268,7 @@ class SandboxFileSystem(SandboxAction):
                                     except:
                                         file_event.content = None
 
-                                await asyncio.create_task(asyncio.coroutine(callback)(file_event))
+                                await callback(file_event)
                             except json.JSONDecodeError:
                                 continue
                             except Exception as e:
@@ -259,8 +286,8 @@ class SandboxFileSystem(SandboxAction):
         return {"close": close}
 
     def format_path(self, path: str) -> str:
-        if path == "/" or path == "":
-            return "%2F"
-        if path.startswith("/"):
-            path = path[1:]
+        """Format path for filesystem operations.
+
+        Simplified to match TypeScript behavior - returns path as-is.
+        """
         return path
