@@ -10,7 +10,7 @@ from ..client.api.compute.update_sandbox import asyncio as update_sandbox
 from ..client.client import client
 from ..client.models import Metadata, Runtime, Sandbox, SandboxSpec
 from ..client.types import UNSET
-from ..common.settings import settings
+from .codegen import SandboxCodegen
 from .filesystem import SandboxFileSystem
 from .network import SandboxNetwork
 from .preview import SandboxPreviews
@@ -27,14 +27,33 @@ logger = logging.getLogger(__name__)
 
 
 class SandboxInstance:
-    def __init__(self, sandbox: Sandbox):
-        self.sandbox = sandbox
-        self.config = SandboxConfiguration(sandbox)
-        self.fs = SandboxFileSystem(self.config)
+    def __init__(
+        self,
+        sandbox: Union[Sandbox, SandboxConfiguration],
+        force_url: str | None = None,
+        headers: Dict[str, str] | None = None,
+        params: Dict[str, str] | None = None,
+    ):
+        # Handle both Sandbox and SandboxConfiguration inputs
+        if isinstance(sandbox, SandboxConfiguration):
+            self.config = sandbox
+            self.sandbox = sandbox.sandbox
+        else:
+            # Create SandboxConfiguration with optional parameters
+            self.sandbox = sandbox
+            self.config = SandboxConfiguration(
+                sandbox=sandbox,
+                force_url=force_url,
+                headers=headers,
+                params=params,
+            )
+
         self.process = SandboxProcess(self.config)
-        self.previews = SandboxPreviews(sandbox)
+        self.fs = SandboxFileSystem(self.config, self.process)
+        self.previews = SandboxPreviews(self.sandbox)
         self.sessions = SandboxSessions(self.config)
         self.network = SandboxNetwork(self.config)
+        self.codegen = SandboxCodegen(self.config)
 
     @property
     def metadata(self):
@@ -64,10 +83,8 @@ class SandboxInstance:
         sandbox: Union[Sandbox, SandboxCreateConfiguration, Dict[str, Any], None] = None,
         safe: bool = True,
     ) -> "SandboxInstance":
-        # Generate default values
-        env = settings.env
         default_name = f"sandbox-{uuid.uuid4().hex[:8]}"
-        default_image = f"blaxel/{env}-base:latest"
+        default_image = "blaxel/base-image:latest"
         default_memory = 4096
 
         # Handle SandboxCreateConfiguration or simple dict with name/image/memory/ports/envs/volumes keys
@@ -88,6 +105,7 @@ class SandboxInstance:
                     or "expires" in (sandbox if isinstance(sandbox, dict) else sandbox.__dict__)
                     or "region" in (sandbox if isinstance(sandbox, dict) else sandbox.__dict__)
                     or "lifecycle" in (sandbox if isinstance(sandbox, dict) else sandbox.__dict__)
+                    or "snapshot_enabled" in (sandbox if isinstance(sandbox, dict) else sandbox.__dict__)
                 )
             )
         ):
@@ -107,6 +125,7 @@ class SandboxInstance:
             expires = sandbox.expires
             region = sandbox.region
             lifecycle = sandbox.lifecycle
+            snapshot_enabled = sandbox.snapshot_enabled
 
             # Create full Sandbox object
             sandbox = Sandbox(
@@ -259,7 +278,15 @@ class SandboxInstance:
                 if not name:
                     raise ValueError("Sandbox name is required")
 
+                # Get the existing sandbox to check its status
                 sandbox_instance = await cls.get(name)
+
+                # If the sandbox is TERMINATED, treat it as not existing
+                if sandbox_instance.status == "TERMINATED":
+                    # Create a new sandbox - backend will handle cleanup of the terminated one
+                    return await cls.create(sandbox)
+
+                # Otherwise return the existing active sandbox
                 return sandbox_instance
             raise e
 
@@ -274,20 +301,11 @@ class SandboxInstance:
         # Create a minimal sandbox configuration for session-based access
         sandbox_name = session.name.split("-")[0] if "-" in session.name else session.name
         sandbox = Sandbox(metadata=Metadata(name=sandbox_name))
-        config = SandboxConfiguration(
+
+        # Use the constructor with force_url, headers, and params
+        return cls(
             sandbox=sandbox,
             force_url=session.url,
             headers={"X-Blaxel-Preview-Token": session.token},
             params={"bl_preview_token": session.token},
         )
-
-        instance = cls.__new__(cls)
-        instance.sandbox = sandbox
-        instance.config = config
-        instance.fs = SandboxFileSystem(config)
-        instance.process = SandboxProcess(config)
-        instance.previews = SandboxPreviews(sandbox)
-        instance.sessions = SandboxSessions(config)
-        instance.network = SandboxNetwork(config)
-
-        return instance
